from PyQt5.QtWidgets import QVBoxLayout, QWidget, QPushButton
from PyQt5.QtCore import Qt, QObject, pyqtSignal, pyqtSlot

from ..models import RQModel, RQList

from typing import List


class RQWidget(QWidget):
    """model: RQModel

    def _rq_widget_init(self):
        self.model._rq_data_changed.emit()"""

    pass
